@@ -162,6 +162,7 @@ def cmd_install(args):
             developer_mode=args.develop,
             enable_prometheus_exporter=args.enable_prometheus_exporter,
             default_boot_mode='uefi' if args.uefi else 'bios',
+            include_dhcp_server=not args.disable_dhcp,
             extra_vars=args.extra_vars,
             **kwargs)
     log("Ironic is installed and running, try it yourself:\n",
@@ -171,6 +172,21 @@ def cmd_install(args):
         "See documentation for next steps")
 
 
+def cmd_enroll(args):
+    inventory = os.path.join(PLAYBOOKS, 'inventory', 'bifrost_inventory.py')
+    if os.path.exists(args.inventory):
+        nodes_inventory = os.path.abspath(args.inventory)
+        os.environ['BIFROST_INVENTORY_SOURCE'] = nodes_inventory
+    else:
+        sys.exit('Inventory file %s cannot be found' % args.inventory)
+
+    ansible('enroll-dynamic.yaml',
+            inventory=inventory,
+            verbose=args.debug,
+            inspect_nodes=args.inspect,
+            extra_vars=args.extra_vars)
+
+
 def parse_args():
     parser = argparse.ArgumentParser("Bifrost CLI")
     parser.add_argument('--debug', action='store_true',
@@ -212,7 +228,7 @@ def parse_args():
     install.set_defaults(func=cmd_install)
     install.add_argument('--testenv', action='store_true',
                          help='running in a virtual environment')
-    install.add_argument('--develop', action='store_true', default=False,
+    install.add_argument('--develop', action='store_true',
                          help='install packages in development mode')
     install.add_argument('--dhcp-pool', metavar='START-END',
                          help='DHCP pool to use')
@@ -232,17 +248,28 @@ def parse_args():
                          help='a comma separated list of enabled bare metal '
                               'hardware types')
     install.add_argument('--cleaning-disk-erase',
-                         action='store_true', default=False,
+                         action='store_true',
                          help='enable full disk cleaning between '
                               'deployments (can take a lot of time)')
     install.add_argument('--enable-prometheus-exporter', action='store_true',
-                         default=False,
                          help='Enable Ironic Prometheus Exporter')
     install.add_argument('--uefi', action='store_true',
                          help='use UEFI by default')
+    install.add_argument('--disable-dhcp', action='store_true',
+                         help='Disable integrated dhcp server')
     install.add_argument('-e', '--extra-vars', action='append',
                          help='additional vars to pass to ansible')
 
+    enroll = subparsers.add_parser(
+        'enroll', help='Enroll bare metal nodes')
+    enroll.set_defaults(func=cmd_enroll)
+    enroll.add_argument('inventory', default='baremetal-inventory.json',
+                        help='file with the inventory')
+    enroll.add_argument('--inspect', action='store_true',
+                        help='inspect nodes while enrolling')
+    enroll.add_argument('-e', '--extra-vars', action='append',
+                        help='additional vars to pass to ansible')
+
     args = parser.parse_args()
     if getattr(args, 'func', None) is None:
         parser.print_usage(file=sys.stderr)
