@@ -19,7 +19,7 @@ export LANG=en_US.UTF-8
 export VENV=${VENV:-/opt/stack/bifrost}
 
 # NOTE(dtantsur): change this when creating a stable branch
-BRANCH=${ZUUL_BRANCH:-victoria}
+BRANCH=${ZUUL_BRANCH:-master}
 CONSTRAINTS_FILE=${UPPER_CONSTRAINTS_FILE:-${TOX_CONSTRAINTS_FILE:-https://releases.openstack.org/constraints/upper/$BRANCH}}
 
 CHECK_CMD_PKGS=(
@@ -73,7 +73,7 @@ case ${ID,,} in
 
     rhel|fedora|centos)
     OS_FAMILY="RedHat"
-    PKG_MANAGER=$(/usr/bin/which dnf || /usr/bin/which yum)
+    PKG_MANAGER=$(which dnf || which yum)
     if [[ "${BIFROST_TRACE:-}" != true ]]; then
         PKG_MANAGER="$PKG_MANAGER --quiet"
     fi
@@ -147,6 +147,11 @@ fi
 
 export PIP_OPTS="--upgrade-strategy only-if-needed"
 
+if [[ $OS_FAMILY == "Suse" ]]; then
+    # https://storyboard.openstack.org/#!/story/2008591
+    ${PIP} install -U setuptools
+fi
+
 echo "Installing bindep"
 ${PIP} install bindep
 
